"""
    금감원 API 안내: https://www.fss.or.kr/fss/main/contents.do?menuNo=201042
"""
import requests
import pandas as pd

# API 호출 함수
def fetch_retirement_data(pen_type, api_key, year, quarter, sys_type):
    """
    퇴직연금 데이터 호출 함수

    :param api_key: API 인증키
    :param year: 조회 연도
    :param quarter: 조회 분기
    :param sys_type: 권역 구분 (1~5)
    :return: 응답 데이터 (list 형식)
    """
    url_dict = {
        "퇴직연금":"https://www.fss.or.kr/openapi/api/rpCorpResultList.json",
        "연금저축":"https://www.fss.or.kr/openapi/api/psCorpList.json"
        }
    
    url = url_dict.get(pen_type)

    if url==None:
        raise Exception("Wrong pen type")

    params = {
        "key": api_key,
        "year": year,
        "quarter": quarter,
        # "sysType": sys_type,
    }
    response = requests.get(url, params=params)
    response.raise_for_status()
    print(response)
    data = response.json()
    return data.get("list", [])

# 데이터 처리 및 시각화
def compare_annual_returns(api_key, pen_type, year, quarter):
    """
    권역별 1년 수익률 비교

    :param api_key: API 인증키
    :param year: 조회 연도
    """
    if pen_type=="퇴직연금":
        sys_types = [1, 2, 3, 4, 5]  # 권역 구분
        all_data = []

        for sys_type in sys_types:
            data = fetch_retirement_data(pen_type, api_key, year, quarter, sys_type)  # 1분기 데이터 사용        
            for item in data:
                area = item["area"]
                company = item["company"]

                for d in item['list']:
                    division = d['division']
                    db_rate = d.get("dbEarnRate", None)
                    dc_rate = d.get("dcEarnRate", None)
                    irp_rate = d.get("irpEarnRate", None)
                    all_data.append({
                        "권역": area,
                        "회사": company,
                        "상품구분": division,
                        "DB 수익률": db_rate,
                        "DC 수익률": dc_rate,
                        "IRP 수익률": irp_rate 
                    })

        # 데이터프레임 생성
        df = pd.DataFrame(all_data)

        # 권역별 평균 수익률 계산
        avg_returns = df.groupby("권역")[["DB 수익률", "DC 수익률", "IRP 수익률"]].mean()
    elif pen_type=="연금저축":
        # area code가 맞지 않아 그냥 전체 데이터가 다 나옴.
        data = fetch_retirement_data(pen_type, api_key, year, quarter, 1)  # 1분기 데이터 사용        

        # 데이터프레임 생성
        df = pd.DataFrame(data)        

    return df

if __name__=="__main__":
    FSS_API = "API키 입력"
    
    year = 2024
    quarter = 3

    df = compare_annual_returns(FSS_API, "연금저축", year, quarter)
    print(df.describe().T)
    print(df.groupby("area").describe().T)

